# rgb_to_hex()

## How to use

```python
from colorcodetools.rgb.convert import RgbToCymk
rgb_to_hex = RgbToCymk()
rgb_to_hex.rgb_to_cymk("(134, 128, 76)")
   ```

## Parameters

1. Required parameters:

   - rgb:  
      Enter rgb code which should be converted.
     - `type: string`
     - `default: None`
     - `example: '(255, 255, 255)'`

## Return value

- `type: boolean or string`
